Index: content/public/browser/host_zoom_map.h |
diff --git a/content/public/browser/host_zoom_map.h b/content/public/browser/host_zoom_map.h |
index 653d24882fe0c5532e15524bf44129373748f276..a4aca1d232f6a97423333490ad242b6d32e06842 100644 |
--- a/content/public/browser/host_zoom_map.h |
+++ b/content/public/browser/host_zoom_map.h |
@@ -37,11 +37,13 @@ class HostZoomMap { |
public: |
// Enum that indicates what was the scope of zoom level change. |
enum ZoomLevelChangeMode { |
- ZOOM_CHANGED_FOR_HOST, // Zoom level changed for host. |
- ZOOM_CHANGED_FOR_SCHEME_AND_HOST, // Zoom level changed for scheme/host |
- // pair. |
- ZOOM_CHANGED_TEMPORARY_ZOOM, // Temporary zoom change for specific |
- // renderer, no scheme/host is specified. |
+ ZOOM_CHANGED_FOR_HOST, // Zoom level changed for host. |
+ ZOOM_CHANGED_FOR_SCHEME_AND_HOST, // Zoom level changed for scheme/host |
+ // pair. |
+ ZOOM_CHANGED_TEMPORARY_ZOOM, // Temporary zoom change for specific |
+ // renderer, no scheme/host is specified. |
+ PAGE_SCALE_IS_ONE_CHANGED, // Page scale factor equal to one changed |
+ // for a host. |
}; |
// Structure used to notify about zoom changes. Host and/or scheme are empty |
@@ -77,6 +79,10 @@ class HostZoomMap { |
// temporary or host-specific. |
CONTENT_EXPORT static double GetZoomLevel(const WebContents* web_contents); |
+ // Returns true if the page scale factor for the WebContents is one. |
+ CONTENT_EXPORT static bool PageScaleFactorIsOne( |
+ const WebContents* web_contents); |
+ |
// Sets the current zoom level for the specified WebContents. The level may |
// be temporary or host-specific depending on the particular WebContents. |
CONTENT_EXPORT static void SetZoomLevel(const WebContents* web_contents, |
@@ -87,6 +93,12 @@ class HostZoomMap { |
CONTENT_EXPORT static void SendErrorPageZoomLevelRefresh( |
const WebContents* web_contents); |
+ // Set or clear whether or not the page scale factor for a view is one. |
+ virtual void SetPageScaleFactorIsOneForView( |
+ int render_process_id, int render_view_id, bool is_one) = 0; |
+ virtual void ClearPageScaleFactorIsOneForView( |
+ int render_process_id, int render_view_id) = 0; |
+ |
// Copy the zoom levels from the given map. Can only be called on the UI |
// thread. |
virtual void CopyFrom(HostZoomMap* copy) = 0; |